@@ -1,5 +1,6 @@
 
 #' @importFrom XML xmlParse xmlToList xmlToDataFrame
+#' @importFrom utils download.file
 #' @import dplyr
 
 # given a catalogue number, download the catalogue metadata via XML, then find
@@ -27,7 +28,11 @@ get_abs_xml_metadata <- function(url, release_dates = "latest") {
   # for a readable XML file using the table number supplied (eg. "1"); if that
   # doesn't work then we try with a leading zero ("01"). If that fails, it's an error.
 
-  first_page <- XML::xmlParse(first_url)
+  first_page_location <- file.path(tempdir(), "temp_readabs_xml.xml")
+
+  utils::download.file(first_url, first_page_location, quiet = TRUE)
+
+  first_page <- XML::xmlParse(first_page_location)
 
   first_page_list <- XML::xmlToList(first_page)
 
@@ -35,14 +40,16 @@ get_abs_xml_metadata <- function(url, release_dates = "latest") {
 
   if(!first_url_works){
     if(!grepl("ttitle", first_url)) { # this is the case when tables == "all"
-      stop(paste0("Cannot find valid entry for cat_no ", cat_no, " in the ABS Time Series Directory"))
+      stop(paste0("Cannot find valid entry for cat_no ", cat_no, " in the ABS Time Series Directory. Check that the cat. no. is correct, and that it contains time series spreadsheets (not data cubes)."))
     }
 
     # now try prepending a 0 on the ttitle
 
     first_url <- gsub("ttitle=", "ttitle=0", first_url)
 
-    first_page <- XML::xmlParse(first_url)
+    utils::download.file(first_url, first_page_location, quiet = TRUE)
+
+    first_page <- XML::xmlParse(first_page_location)
 
     first_page_list <- XML::xmlToList(first_page)
 
